summaryrefslogtreecommitdiff
path: root/src/d/actor/d_a_gy_ctrl.cpp
diff options
context:
space:
mode:
authorLagoLunatic <LagoLunatic@users.noreply.github.com>2026-05-26 00:11:58 -0400
committerGitHub <noreply@github.com>2026-05-26 00:11:58 -0400
commit102042628fa139f4e509251bdd9095493f031e28 (patch)
treea5b37fcd76d8c0105f2e9b379b7e2daa7eae2266 /src/d/actor/d_a_gy_ctrl.cpp
parent79277cb2b2672104b87172d8ff620f923f450658 (diff)
Process profiles and enums cleanup (#1031)
* Fix some profile comments * Add missing static for local visibility data * Move proc name and draw priority enums to f_pc * Add _e suffix to daObjBarrier_c proc enum * Change proc name enum format to match TP * Change draw prio enum format to match TP * Change ItemNo enum format, finish fixing item names * Revert static for cb1 hio * Clean up formatting of profile comments * Fix comment alignment
Diffstat (limited to 'src/d/actor/d_a_gy_ctrl.cpp')
-rw-r--r--src/d/actor/d_a_gy_ctrl.cpp40
1 files changed, 19 insertions, 21 deletions
diff --git a/src/d/actor/d_a_gy_ctrl.cpp b/src/d/actor/d_a_gy_ctrl.cpp
index 083ade20..e3977879 100644
--- a/src/d/actor/d_a_gy_ctrl.cpp
+++ b/src/d/actor/d_a_gy_ctrl.cpp
@@ -9,8 +9,6 @@
#if VERSION > VERSION_DEMO
#include "d/actor/d_a_gy.h"
#endif
-#include "d/d_procname.h"
-#include "d/d_priority.h"
#if VERSION > VERSION_DEMO
#include "d/d_s_play.h"
#endif
@@ -72,11 +70,11 @@ void* searchNearActor_CB(void* arg0, void* arg1) {
void* daGy_Ctrl_c::searchNearActor(fopAc_ac_c* arg1) {
if (fopAc_IsActor(arg1)) {
f32 dVar3 = fopAcM_searchActorDistanceXZ(this, arg1);
- if (m328 == 0 && fpcM_GetName(arg1) == PROC_GY_CTRLB && dVar3 < 6000.0f) {
+ if (m328 == 0 && fpcM_GetName(arg1) == fpcNm_GY_CTRLB_e && dVar3 < 6000.0f) {
return arg1;
}
- if (fpcM_GetName(arg1) == PROC_DAIOCTA || fpcM_GetName(arg1) == PROC_OBJ_IKADA || fpcM_GetName(arg1) == PROC_NPC_SO) {
+ if (fpcM_GetName(arg1) == fpcNm_DAIOCTA_e || fpcM_GetName(arg1) == fpcNm_OBJ_IKADA_e || fpcM_GetName(arg1) == fpcNm_NPC_SO_e) {
if (dVar3 < 6000.0f) {
return arg1;
}
@@ -344,7 +342,7 @@ void daGy_Ctrl_c::modeCreate() {
sp10.y = m308[m31C];
sp18.y = -1000.0f;
- m360[m31C] = fopAcM_createChild(PROC_GY, fopAcM_GetID(this), 0xffffffff, &sp18, tevStr.mRoomNo, &sp10);
+ m360[m31C] = fopAcM_createChild(fpcNm_GY_e, fopAcM_GetID(this), 0xffffffff, &sp18, tevStr.mRoomNo, &sp10);
m374[m31C] = true;
m350 = l_HIO.m08;
}
@@ -521,7 +519,7 @@ void daGy_Ctrl_c::getArg() {
/* 000013F8-00001458 .text checkGyCtrlExist__11daGy_Ctrl_cFv */
bool daGy_Ctrl_c::checkGyCtrlExist() {
- s32 local_8 = PROC_GY_CTRL;
+ s32 local_8 = fpcNm_GY_CTRL_e;
daGy_Ctrl_c* pfVar1 = (daGy_Ctrl_c*)fopAcM_SearchByName(local_8);
if ((pfVar1 != NULL) && (pfVar1->m328 == 0) && (pfVar1->m331 == 1)) {
return true;
@@ -539,7 +537,7 @@ cPhs_State daGy_Ctrl_c::_create() {
return cPhs_ERROR_e;
}
- if (!dComIfGs_checkGetItem(dItem_BOOMERANG_e)) {
+ if (!dComIfGs_checkGetItem(dItemNo_BOOMERANG_e)) {
return cPhs_ERROR_e;
}
@@ -586,35 +584,35 @@ static actor_method_class daGy_CtrlMethodTable = {
};
actor_process_profile_definition g_profile_GY_CTRL = {
/* LayerID */ fpcLy_CURRENT_e,
/* ListID */ 0x0007,
/* ListPrio */ fpcPi_CURRENT_e,
/* ProcName */ PROC_GY_CTRL,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(daGy_Ctrl_c),
- /* SizeOther */ 0,
+ /* Size Other */ 0,
/* Parameters */ 0,
/* Leaf SubMtd */ &g_fopAc_Method.base,
- /* Priority */ PRIO_GY_CTRL,
+ /* Draw Prio */ fpcDwPi_GY_CTRL_e,
/* Actor SubMtd */ &daGy_CtrlMethodTable,
/* Status */ fopAcStts_UNK40000_e,
/* Group */ fopAc_ACTOR_e,
- /* CullType */ fopAc_CULLBOX_4_e,
+ /* Cull Type */ fopAc_CULLBOX_4_e,
};
actor_process_profile_definition g_profile_GY_CTRLB = {
/* LayerID */ fpcLy_CURRENT_e,
/* ListID */ 0x0007,
/* ListPrio */ fpcPi_CURRENT_e,
/* ProcName */ PROC_GY_CTRLB,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(daGy_Ctrl_c),
- /* SizeOther */ 0,
+ /* Size Other */ 0,
/* Parameters */ 0,
/* Leaf SubMtd */ &g_fopAc_Method.base,
- /* Priority */ PRIO_GY_CTRLB,
+ /* Draw Prio */ fpcDwPi_GY_CTRLB_e,
/* Actor SubMtd */ &daGy_CtrlMethodTable,
/* Status */ fopAcStts_UNK40000_e,
/* Group */ fopAc_ACTOR_e,
- /* CullType */ fopAc_CULLBOX_4_e,
+ /* Cull Type */ fopAc_CULLBOX_4_e,
};
@@ -586,35 +584,35 @@ static actor_method_class daGy_CtrlMethodTable = {
};
actor_process_profile_definition g_profile_GY_CTRL = {
- /* LayerID */ fpcLy_CURRENT_e,
- /* ListID */ 0x0007,
- /* ListPrio */ fpcPi_CURRENT_e,
- /* ProcName */ PROC_GY_CTRL,
+ /* Layer ID */ fpcLy_CURRENT_e,
+ /* List ID */ 0x0007,
+ /* List Prio */ fpcPi_CURRENT_e,
+ /* Proc Name */ fpcNm_GY_CTRL_e,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(daGy_Ctrl_c),
@@ -586,35 +584,35 @@ static actor_method_class daGy_CtrlMethodTable = {
};
actor_process_profile_definition g_profile_GY_CTRLB = {
- /* LayerID */ fpcLy_CURRENT_e,
- /* ListID */ 0x0007,
- /* ListPrio */ fpcPi_CURRENT_e,
- /* ProcName */ PROC_GY_CTRLB,
+ /* Layer ID */ fpcLy_CURRENT_e,
+ /* List ID */ 0x0007,
+ /* List Prio */ fpcPi_CURRENT_e,
+ /* Proc Name */ fpcNm_GY_CTRLB_e,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(daGy_Ctrl_c),